@@ -15,5 +15,5 @@ void PcapFilter::callback(PcapFilter *pf, struct pcap_pkthdr const *hdr,
     if (pf->d_options.hasProtocol(
                 IP_Types::get<IP_Types::IP_Header>(packet).protocol)
     )
-        pf->d_storage.push( PcapRecord{ pf->d_type, *hdr, packet } );
+        pf->d_storage.push( new PcapRecord{ pf->d_type, *hdr, packet } );
 }
